Index: trunk/pstamp/scripts/pstamp_webrequest.pl
===================================================================
--- trunk/pstamp/scripts/pstamp_webrequest.pl	(revision 28106)
+++ trunk/pstamp/scripts/pstamp_webrequest.pl	(revision 29085)
@@ -4,5 +4,5 @@
 # pstampwebrequest.pl: take a postage stamp request command line and process it
 #
 # The arguments are the command line parameters for the program pstamprequest
 #
 # Unless the argument -list is provided the output is the request id for the resulting request
@@ -70,8 +70,7 @@
 my $missing_tools;
 
-my $pstamprequest = can_run('pstamprequest')  or (warn "Can't find pstamprequest"  and $missing_tools = 1);
+my $psmkreq = can_run('psmkreq')  or (warn "Can't find psmkreq"  and $missing_tools = 1);
 my $pstamptool = can_run('pstamptool')  or (warn "Can't find pstamptool"  and $missing_tools = 1);
 my $pstampparse = can_run('pstampparse.pl')  or (warn "Can't find pstampparse.pl"  and $missing_tools = 1);
-my $pstampparser_run = can_run('pstamp_parser_run.pl')  or (warn "Can't find pstamp_parser_run.pl"  and $missing_tools = 1);
 
 if ($missing_tools) {
@@ -96,6 +95,5 @@
 my $request_file = "$datedir/$request_name.fits";
 {
-    my $command = "$pstamprequest -req_name $request_name -project $project $request_file @ARGV";
-    $command .= " -$job_type" if $job_type;     # default job_type is pstamp
+    my $command = "$psmkreq --req_name $request_name  --output $request_file @ARGV";
 
     my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
@@ -103,5 +101,5 @@
     unless ($success) {
         print STDERR @$stderr_buf;
-        die("Unable to perform pstamprequest: $error_code");
+        die("Unable to perform psmkreq: $error_code");
     }
 }
@@ -4,5 +4,5 @@
 # pstampwebrequest.pl: take a postage stamp request command line and process it
 #
-# The arguments are the command line parameters for the program pstamprequest
+# The arguments are the command line parameters for the program psmkreq
 #
 # Unless the argument -list is provided the output is the request id for the resulting request
